v{{ changelog_entry.version }} {% if changelog_entry.type == 'bug' %} {% include 'django_spire/badge/danger_badge.html' with badge_text=changelog_entry.type.label %} {% elif changelog_entry.type == 'feat' %} {% include 'django_spire/badge/success_badge.html' with badge_text=changelog_entry.type.label %} {% else %} {% include 'django_spire/badge/primary_badge.html' with badge_text=changelog_entry.type.label %} {% endif %} {{ changelog_entry.date|date:"Y-m-d" }}
{% for change in changelog_entry.changes %}
{% include 'django_spire/badge/secondary_outlined_badge.html' with badge_text=change.app|title %} {{ change.description }}
{% endfor %}